@@ -1,5 +1,5 @@
 __author__ = 'Andrea De Marco <24erre@gmail.com>'
-__version__ = '1.0.1'
+__version__ = '1.1'
 __classifiers__ = [
     'Development Status :: 5 - Production/Stable',
     'Intended Audience :: Developers',
@@ -53,9 +53,14 @@ def parse_args():
     args.data_file = os.path.join(args.base_dir, args.data_file)
     args.config_file = os.path.join(args.base_dir, args.config_file)
     args.coveralls_yaml = os.path.join(args.base_dir, args.coveralls_yaml)
-    with open(args.coveralls_yaml, 'r') as fp:
-        yml = yaml.load(fp)
-    args.repo_token = yml['repo_token']
+    yml = {}
+    try:
+        with open(args.coveralls_yaml, 'r') as fp:
+            yml = yaml.load(fp)
+    except:
+        pass
+    yml = yml or {}
+    args.repo_token = yml.get('repo_token', '')
     args.service_name = yml.get('service_name', 'travis-ci')
     args.service_job_id = os.environ.get('TRAVIS_JOB_ID', '')
     return args
@@ -76,4 +81,5 @@ def wear(args=None):
         git=gitrepo(args.base_dir),
         source_files=coverage.coveralls(args.base_dir),
     )
+    print response.text
     return response
