@@ -4,11 +4,13 @@ import requests
 
 
 def post(url, repo_token, service_job_id, service_name, git, source_files):
-    json_file = StringIO(json.dumps({
-        'repo_token': repo_token,
+    content = {
         'service_job_id': service_job_id,
         'service_name': service_name,
         'git': git,
         'source_files': source_files,
-    }))
+    }
+    if repo_token:
+        content['repo_token'] = repo_token
+    json_file = StringIO(json.dumps(content))
     return requests.post(url, files={'json_file': json_file})
